@@ -82,7 +82,7 @@ def _decode_int(n):
     return int(hexlify(n), 16)
 
 
-class _RawJWS(object):
+class _RawJWS:
 
     def sign(self, key, payload):
         raise NotImplementedError
@@ -333,7 +333,7 @@ class _None(_RawNone, JWAAlgorithm):
     algorithm_use = 'sig'
 
 
-class _RawKeyMgmt(object):
+class _RawKeyMgmt:
 
     def wrap(self, key, bitsize, cek, headers):
         raise NotImplementedError
@@ -353,7 +353,7 @@ class _RSA(_RawKeyMgmt):
         if key['kty'] != 'RSA':
             raise InvalidJWEKeyType('RSA', key['kty'])
 
-    # FIXME: get key size and insure > 2048 bits
+    # FIXME: get key size and ensure > 2048 bits
     def wrap(self, key, bitsize, cek, headers):
         self._check_key(key)
         if not cek:
@@ -364,7 +364,7 @@ class _RSA(_RawKeyMgmt):
 
     def unwrap(self, key, bitsize, ek, headers):
         self._check_key(key)
-        rk = key.get_op_key('decrypt')
+        rk = key.get_op_key('unwrapKey')
         cek = rk.decrypt(ek, self.padfn)
         if _bitsize(cek) != bitsize:
             raise InvalidJWEKeyLength(bitsize, _bitsize(cek))
@@ -581,7 +581,7 @@ class _Pbes2HsAesKw(_RawKeyMgmt):
 
     def _get_key(self, alg, key, p2s, p2c):
         if not isinstance(key, JWK):
-            # backwards compatiblity for old interface
+            # backwards compatibility for old interface
             if isinstance(key, bytes):
                 plain = key
             else:
@@ -836,7 +836,6 @@ class _EdDsa(_RawJWS, JWAAlgorithm):
     keysize = None
 
     def sign(self, key, payload):
-
         if key['crv'] in ['Ed25519', 'Ed448']:
             skey = key.get_op_key('sign')
             return skey.sign(payload)
@@ -849,7 +848,7 @@ class _EdDsa(_RawJWS, JWAAlgorithm):
         raise NotImplementedError
 
 
-class _RawJWE(object):
+class _RawJWE:
 
     def encrypt(self, k, a, m):
         raise NotImplementedError
@@ -1042,7 +1041,7 @@ class _A256Gcm(_AesGcm, JWAAlgorithm):
     algorithm_use = 'enc'
 
 
-class JWA(object):
+class JWA:
     """JWA Signing Algorithms.
 
     This class provides access to all JWA algorithms.
@@ -1101,7 +1100,7 @@ class JWA(object):
         try:
             return cls.instantiate_alg(name, use='sig')
         except KeyError:
-            raise InvalidJWAAlgorithm('%s is not a valid Signign algorithm'
+            raise InvalidJWAAlgorithm('%s is not a valid Signing algorithm'
                                       ' name' % name) from None
 
     @classmethod
