@@ -18,7 +18,7 @@ from jwcrypto.common import base64url_decode, base64url_encode
 from jwcrypto.common import json_decode, json_encode
 
 
-class UnimplementedOKPCurveKey(object):
+class UnimplementedOKPCurveKey:
     @classmethod
     def generate(cls):
         raise NotImplementedError
@@ -243,7 +243,7 @@ class InvalidJWKOperation(JWException):
             op = JWKOperationsRegistry[self.op]
         else:
             op = 'Unknown(%s)' % self.op
-        valid = list()
+        valid = []
         for v in self.values:
             if v in list(JWKOperationsRegistry.keys()):
                 valid.append(JWKOperationsRegistry[v])
@@ -265,7 +265,7 @@ class InvalidJWKValue(JWException):
 class JWK(dict):
     """JSON Web Key object
 
-    This object represent a Key.
+    This object represents a Key.
     It must be instantiated by using the standard defined key/value pairs
     as arguments of the initialization function.
     """
@@ -292,7 +292,7 @@ class JWK(dict):
          * OKP: crv(str) (one of Ed25519, Ed448, X25519, X448)
 
         Deprecated:
-        Alternatively if the 'generate' parameter is provided, with a
+        Alternatively if the 'generate' parameter is provided with a
         valid key type as value then a new key will be generated according
         to the defaults or provided key strength options (type specific).
 
@@ -301,6 +301,8 @@ class JWK(dict):
             are provided.
         """
         super(JWK, self).__init__()
+        self._cache_pub_k = None
+        self._cache_pri_k = None
 
         if 'generate' in kwargs:
             self.generate_key(**kwargs)
@@ -483,8 +485,10 @@ class JWK(dict):
         self.import_key(**params)
 
     def import_key(self, **kwargs):
-        newkey = dict()
+        newkey = {}
         key_vals = 0
+        self._cache_pub_k = None
+        self._cache_pri_k = None
 
         names = list(kwargs.keys())
 
@@ -591,7 +595,7 @@ class JWK(dict):
         """
         if private_key is True:
             # Use _export_all for backwards compatibility, as this
-            # function allows to export symmetrict keys too
+            # function allows to export symmetric keys too
             return self._export_all(as_dict)
 
         return self.export_public(as_dict)
@@ -624,7 +628,7 @@ class JWK(dict):
         return pub
 
     def _export_all(self, as_dict=False):
-        d = dict()
+        d = {}
         d.update(self)
         if as_dict is True:
             return d
@@ -704,7 +708,7 @@ class JWK(dict):
         :param arg: an optional curve name
 
         :raises InvalidJWKType: the key is not an EC or OKP key.
-        :raises InvalidJWKValue: if the curve names is invalid.
+        :raises InvalidJWKValue: if the curve name is invalid.
         """
         crv = self.get('crv')
         if self.get('kty') not in ['EC', 'OKP']:
@@ -730,57 +734,93 @@ class JWK(dict):
     def _decode_int(self, n):
         return int(hexlify(base64url_decode(n)), 16)
 
-    def _rsa_pub(self):
+    def _rsa_pub_n(self):
         e = self._decode_int(self.get('e'))
         n = self._decode_int(self.get('n'))
         return rsa.RSAPublicNumbers(e, n)
 
-    def _rsa_pri(self):
+    def _rsa_pri_n(self):
         p = self._decode_int(self.get('p'))
         q = self._decode_int(self.get('q'))
         d = self._decode_int(self.get('d'))
         dp = self._decode_int(self.get('dp'))
         dq = self._decode_int(self.get('dq'))
         qi = self._decode_int(self.get('qi'))
-        return rsa.RSAPrivateNumbers(p, q, d, dp, dq, qi, self._rsa_pub())
+        return rsa.RSAPrivateNumbers(p, q, d, dp, dq, qi, self._rsa_pub_n())
 
-    def _ec_pub(self, curve):
+    def _rsa_pub(self):
+        k = self._cache_pub_k
+        if k is None:
+            k = self._rsa_pub_n().public_key(default_backend())
+            self._cache_pub_k = k
+        return k
+
+    def _rsa_pri(self):
+        k = self._cache_pri_k
+        if k is None:
+            k = self._rsa_pri_n().private_key(default_backend())
+            self._cache_pri_k = k
+        return k
+
+    def _ec_pub_n(self, curve):
         x = self._decode_int(self.get('x'))
         y = self._decode_int(self.get('y'))
         return ec.EllipticCurvePublicNumbers(x, y, self.get_curve(curve))
 
-    def _ec_pri(self, curve):
+    def _ec_pri_n(self, curve):
         d = self._decode_int(self.get('d'))
-        return ec.EllipticCurvePrivateNumbers(d, self._ec_pub(curve))
+        return ec.EllipticCurvePrivateNumbers(d, self._ec_pub_n(curve))
+
+    def _ec_pub(self, curve):
+        k = self._cache_pub_k
+        if k is None:
+            k = self._ec_pub_n(curve).public_key(default_backend())
+            self._cache_pub_k = k
+        return k
+
+    def _ec_pri(self, curve):
+        k = self._cache_pri_k
+        if k is None:
+            k = self._ec_pri_n(curve).private_key(default_backend())
+            self._cache_pri_k = k
+        return k
 
     def _okp_pub(self):
-        crv = self.get('crv')
-        try:
-            pubkey = _OKP_CURVES_TABLE[crv].pubkey
-        except KeyError as e:
-            raise InvalidJWKValue('Unknown curve "%s"' % crv) from e
+        k = self._cache_pub_k
+        if k is None:
+            crv = self.get('crv')
+            try:
+                pubkey = _OKP_CURVES_TABLE[crv].pubkey
+            except KeyError as e:
+                raise InvalidJWKValue('Unknown curve "%s"' % crv) from e
 
-        x = base64url_decode(self.get('x'))
-        return pubkey.from_public_bytes(x)
+            x = base64url_decode(self.get('x'))
+            k = pubkey.from_public_bytes(x)
+            self._cache_pub_k = k
+        return k
 
     def _okp_pri(self):
-        crv = self.get('crv')
-        try:
-            privkey = _OKP_CURVES_TABLE[crv].privkey
-        except KeyError as e:
-            raise InvalidJWKValue('Unknown curve "%s"' % crv) from e
+        k = self._cache_pri_k
+        if k is None:
+            crv = self.get('crv')
+            try:
+                privkey = _OKP_CURVES_TABLE[crv].privkey
+            except KeyError as e:
+                raise InvalidJWKValue('Unknown curve "%s"' % crv) from e
 
-        d = base64url_decode(self.get('d'))
-        return privkey.from_private_bytes(d)
+            d = base64url_decode(self.get('d'))
+            k = privkey.from_private_bytes(d)
+            self._cache_pri_k = k
+        return k
 
     def _get_public_key(self, arg=None):
         ktype = self.get('kty')
         if ktype == 'oct':
             return self.get('k')
         elif ktype == 'RSA':
-            return self._rsa_pub().public_key(default_backend())
+            return self._rsa_pub()
         elif ktype == 'EC':
-            return self._ec_pub(arg).public_key(default_backend())
+            return self._ec_pub(arg)
         elif ktype == 'OKP':
             return self._okp_pub()
         else:
@@ -791,9 +831,9 @@ class JWK(dict):
         if ktype == 'oct':
             return self.get('k')
         elif ktype == 'RSA':
-            return self._rsa_pri().private_key(default_backend())
+            return self._rsa_pri()
         elif ktype == 'EC':
-            return self._ec_pri(arg).private_key(default_backend())
+            return self._ec_pri(arg)
         elif ktype == 'OKP':
             return self._okp_pri()
         else:
@@ -807,7 +847,7 @@ class JWK(dict):
         :param operation: The requested operation.
          The valid set of operations is available in the
          :data:`JWKOperationsRegistry` registry.
-        :param arg: an optional, context specific, argument
+        :param arg: An optional, context specific, argument.
          For example a curve name.
 
         :raises InvalidJWKOperation: if the operation is unknown or
@@ -969,6 +1009,9 @@ class JWK(dict):
 
         # Check if item is a key value and verify its format
         if item in list(JWKValuesRegistry[kty].keys()):
+            # Invalidate cached keys if any
+            self._cache_pub_k = None
+            self._cache_pri_k = None
             if JWKValuesRegistry[kty][item].type == ParmType.b64:
                 try:
                     v = base64url_decode(value)
@@ -1028,6 +1071,12 @@ class JWK(dict):
                 if self.get(name) is not None:
                     raise KeyError("Cannot remove 'kty', values present")
 
+        kty = self.get('kty')
+        if kty is not None and item in list(JWKValuesRegistry[kty].keys()):
+            # Invalidate cached keys if any
+            self._cache_pub_k = None
+            self._cache_pri_k = None
+
         super(JWK, self).__delitem__(item)
 
     def __eq__(self, other):
@@ -1082,7 +1131,7 @@ class JWK(dict):
 
     # Prevent accidental disclosure of key material via repr()
     def __repr__(self):
-        repr_dict = dict()
+        repr_dict = {}
         repr_dict['kid'] = self.get('kid', 'Missing Key ID')
         repr_dict['thumbprint'] = self.thumbprint()
         return json_encode(repr_dict)
@@ -1147,10 +1196,10 @@ class JWKSet(dict):
         :param as_dict(bool): Whether to return a dict instead of
                               a JSON object
         """
-        exp_dict = dict()
+        exp_dict = {}
         for k, v in self.items():
             if k == 'keys':
-                keys = list()
+                keys = []
                 for jwk in v:
                     keys.append(jwk.export(private_keys, as_dict=True))
                 v = keys
@@ -1199,10 +1248,10 @@ class JWKSet(dict):
         return None
 
     def __repr__(self):
-        repr_dict = dict()
+        repr_dict = {}
         for k, v in self.items():
             if k == 'keys':
-                keys = list()
+                keys = []
                 for jwk in v:
                     keys.append(repr(jwk))
                 v = keys
