@@ -21,9 +21,9 @@ JWTClaimsRegistry = {'iss': 'Issuer',
 
 
 class JWTExpired(JWException):
-    """Json Web Token is expired.
+    """JSON Web Token is expired.
 
-    This exception is raised when a token is expired accoring to its claims.
+    This exception is raised when a token is expired according to its claims.
     """
 
     def __init__(self, message=None, exception=None):
@@ -38,7 +38,7 @@ class JWTExpired(JWException):
 
 
 class JWTNotYetValid(JWException):
-    """Json Web Token is not yet valid.
+    """JSON Web Token is not yet valid.
 
     This exception is raised when a token is not valid yet according to its
     claims.
@@ -56,7 +56,7 @@ class JWTNotYetValid(JWException):
 
 
 class JWTMissingClaim(JWException):
-    """Json Web Token claim is invalid.
+    """JSON Web Token claim is invalid.
 
     This exception is raised when a claim does not match the expected value.
     """
@@ -73,7 +73,7 @@ class JWTMissingClaim(JWException):
 
 
 class JWTInvalidClaimValue(JWException):
-    """Json Web Token claim is invalid.
+    """JSON Web Token claim is invalid.
 
     This exception is raised when a claim does not match the expected value.
     """
@@ -90,7 +90,7 @@ class JWTInvalidClaimValue(JWException):
 
 
 class JWTInvalidClaimFormat(JWException):
-    """Json Web Token claim format is invalid.
+    """JSON Web Token claim format is invalid.
 
     This exception is raised when a claim is not in a valid format.
     """
@@ -108,7 +108,7 @@ class JWTInvalidClaimFormat(JWException):
 
 # deprecated and not used anymore
 class JWTMissingKeyID(JWException):
-    """Json Web Token is missing key id.
+    """JSON Web Token is missing key id.
 
     This exception is raised when trying to decode a JWT with a key set
     that does not have a kid value in its header.
@@ -126,7 +126,7 @@ class JWTMissingKeyID(JWException):
 
 
 class JWTMissingKey(JWException):
-    """Json Web Token is using a key not in the key set.
+    """JSON Web Token is using a key not in the key set.
 
     This exception is raised if the key that was used is not available
     in the passed key set.
@@ -143,7 +143,7 @@ class JWTMissingKey(JWException):
         super(JWTMissingKey, self).__init__(msg)
 
 
-class JWT(object):
+class JWT:
     """JSON Web token object
 
     This object represent a generic token.
@@ -195,6 +195,8 @@ class JWT(object):
             self._reg_claims = default_claims
 
         if check_claims is not None:
+            if check_claims is not False:
+                self._check_check_claims(check_claims)
             self._check_claims = check_claims
 
         if claims is not None:
@@ -302,13 +304,13 @@ class JWT(object):
         self._add_jti_claim(claims)
 
     def _check_string_claim(self, name, claims):
-        if name not in claims:
+        if name not in claims or claims[name] is None:
             return
         if not isinstance(claims[name], str):
             raise JWTInvalidClaimFormat("Claim %s is not a StringOrURI type")
 
     def _check_array_or_string_claim(self, name, claims):
-        if name not in claims:
+        if name not in claims or claims[name] is None:
             return
         if isinstance(claims[name], list):
             if any(not isinstance(claim, str) for claim in claims):
@@ -319,7 +321,7 @@ class JWT(object):
                 "Claim %s is not a StringOrURI type" % (name, ))
 
     def _check_integer_claim(self, name, claims):
-        if name not in claims:
+        if name not in claims or claims[name] is None:
             return
         try:
             int(claims[name])
@@ -353,6 +355,16 @@ class JWT(object):
             if 'nbf' in claims:
                 self._check_nbf(claims['nbf'], time.time(), self._leeway)
 
+    def _check_check_claims(self, check_claims):
+        self._check_string_claim('iss', check_claims)
+        self._check_string_claim('sub', check_claims)
+        self._check_string_claim('aud', check_claims)
+        self._check_integer_claim('exp', check_claims)
+        self._check_integer_claim('nbf', check_claims)
+        self._check_integer_claim('iat', check_claims)
+        self._check_string_claim('jti', check_claims)
+        self._check_string_claim('typ', check_claims)
+
     def _check_provided_claims(self):
         # check_claims can be set to False to skip any check
         if self._check_claims is False:
@@ -484,7 +496,7 @@ class JWT(object):
         if self._algs:
             self.token.allowed_algs = self._algs
 
-        self.deserializelog = list()
+        self.deserializelog = []
         # now deserialize and also decrypt/verify (or raise) if we
         # have a key
         if key is None:
